@@ -84,7 +84,7 @@ class Svtplay(Service, MetadataThumbMixin):
             yield ServiceError("Can't find video id")
             return
 
-        self.outputfilename(video_data)
+        self.outputfilename(video_data, vid)
         self.extrametadata(video_data)
         self.chaptersdata(video_data)
 
@@ -196,7 +196,7 @@ class Svtplay(Service, MetadataThumbMixin):
                 else:
                     yield i
 
-        if check_exists(["sv", "sv-caption"], subs):
+        if not self.config.get("get_all_subtitles") and check_exists(["sv", "sv-caption"], subs):
             for i in subs:
                 if i.subfix == "sv-caption":
                     i.subfix = "sv"
@@ -355,19 +355,25 @@ class Svtplay(Service, MetadataThumbMixin):
                 return episodes[: config.get("all_last")]
         return episodes
 
-    def outputfilename(self, data):
+    def outputfilename(self, data, vid):
         name = None
         desc = None
         modulej = None
+        other = None
 
+        name = data["item"]["parent"]["name"]
         for module in data["modules"]:
             if "analytics" in module and module["analytics"]["json"]["moduleType"] == "Details":
                 modulej = module
         if modulej is None:
             return
-        name = modulej["details"]["heading"]
-        other = modulej["details"]["smartStart"]["item"]["videos"][0]["name"]
-        vid = hashlib.sha256(modulej["details"]["smartStart"]["videoSvtId"].encode("utf-8")).hexdigest()[:7]
+
+        if name is None:
+            name = modulej["details"]["heading"]
+        for i in modulej["details"]["smartStart"]["item"]["videos"]:
+            if vid == i["svtId"]:
+                other = i["name"]
+        vid = hashlib.sha256(vid.encode("utf-8")).hexdigest()[:7]
 
         if name == other:
             other = None
@@ -491,7 +497,7 @@ class Svtplay(Service, MetadataThumbMixin):
                 )
             self.output["publishing_datetime"] = int(date)
 
-        self.output["title_nice"] = modulej["details"]["heading"]
+        self.output["title_nice"] = episode["item"]["parent"]["name"]
 
         try:
             t = episode["item"]["parent"]["image"]["wide"]
